@@ -11,8 +11,11 @@ test_that("create and query mock_fun", {
     "mocked request"
   )
 
-  expect_identical(mock_args(mk, "url"), url)
-  expect_identical(mock_args(mk, "open"), "")
+  expect_type(mock_args(mk), "list")
+  expect_length(mock_args(mk), 3L)
+
+  expect_identical(mock_arg(mk, "url"), url)
+  expect_identical(mock_arg(mk, "open"), "")
 
   skip_if(getRversion() < "3.6.0")
   expect_identical(mock_call(mk), str2lang("curl::curl(url = url)"))
